@@ -1,4 +1,4 @@
-rtrend <- function(x){
+"rtrend" <- function(x){
   for(i in 1:length(x)){
     xx <- x[[i]]$amp
     j <- 1:length(xx)
@@ -7,11 +7,8 @@ rtrend <- function(x){
   return(x)
 }
 
-rmean <- function(x){
+"rmean" <- function(x){
   for(i in 1:length(x))
     x[[i]]$amp <- x[[i]]$amp - mean(x[[i]]$amp)
   return(x)
 }
-
-
-
